@@ -59,6 +59,11 @@ bool AccessRecordWeb::save(const TypingRecorder::GameSettings& data) {
 bool AccessRecordWeb::load(std::vector<TypingRecorder::GameSettings>& data,
                            const char* user_name,
                            time_t from, time_t to, size_t max_num) {
+  static_cast<void>(data);
+  static_cast<void>(user_name);
+  static_cast<void>(from);
+  static_cast<void>(to);
+  static_cast<void>(max_num);
 
   // !!!
   return false;
