@@ -157,6 +157,9 @@ struct ConsolePanelComponent::pImpl {
 
   // Psڂ̍폜ƈʒu̍ĕ]s
   void scrollOut(void) {
+    if (surfaces.empty()) {
+      return;
+    }
 
     //fprintf(stderr, "call scrollOut(): before %d\n", surfaces_size);
 
@@ -176,6 +179,9 @@ struct ConsolePanelComponent::pImpl {
   }
 
   void fadeOut(void) {
+    if (surfaces.empty()) {
+      return;
+    }
 
     // y ̈ʒuXV
     int y_offset = (direction == Down) ? +font_size : -font_size;
