@@ -18,9 +18,9 @@ namespace beego {
 
   typedef std::vector<boost::shared_ptr<TextSurface> > FadeSurfaces;
 
-  typedef enum FadeMode {
+  typedef enum {
     FadeInFromLeft,             //!< Eɕ\
-  };
+  } FadeMode;
 
   class FadeSurfacesInterface {
   public:
