@@ -33,8 +33,8 @@
 #include "CommonResources.h"
 #include "ResourceDefinition.h"
 #include "CommonResources.h"
+#include "UpdateUtils.h"
 #include "AccessSettings.h"
-#include "GuiManager.h"
 #include "Layer.h"
 #include "OptionMenuComponent.h"
 #include "SdlSurface.h"
@@ -47,7 +47,6 @@
 #include "VolumeSliderComponent.h"
 #include "ComboBoxComponent.h"
 #include "ButtonComponent.h"
-#include "InputHandler.h"
 #include "SdlUtils.h"
 #include "Delay.h"
 
@@ -414,18 +413,13 @@ OptionMenu::~OptionMenu(void) {
 
 void OptionMenu::run(void) {
 
-  GuiManager* gui = pimpl->common_->gui_;
-  InputHandler& input = *pimpl->common_->input_;
+  UpdateUtils updater(pimpl->common_);
   bool quit = false;
   while (quit == false) {
 
     // ύX̊ĎAf
     pimpl->updateInput();
-
-    input.update_all();
-    gui->update();
-    quit |= input.haveQuitEvent() | input.isReleased(SDLK_ESCAPE) ||
-      pimpl->escape_button_->isDecided();
+    quit |= updater.update() | pimpl->escape_button_->isDecided();
     delay(1);
   }
 }
