@@ -13,6 +13,9 @@
 #include <memory>
 
 
+/*!
+  \brief [U폜
+*/
 class RemoveUser {
   RemoveUser(const RemoveUser& rhs);
   RemoveUser& operator = (const RemoveUser& rhs);
@@ -24,6 +27,9 @@ public:
   RemoveUser(void);
   ~RemoveUser(void);
 
+  /*!
+    \brief N
+  */
   void run(void);
 };
 
