@@ -9,6 +9,8 @@
 
 #include "SearchFilePath.h"
 #include "ExistFile.h"
+#include <cstdlib>
+#include <cstring>
 
 using namespace beego;
 
