@@ -259,9 +259,8 @@ void ShimonokuInput::drawInput(void) {
   }
 
   // ͌̍XV
-  pimpl->waka_drawer_.updateInputSample(pimpl->judge_text_,
-                                       pimpl->input_complete_, roman_sample,
-                                       need_bs);
+  pimpl->waka_drawer_.updateInputSample(pimpl->input_complete_, roman_sample,
+                                        need_bs);
 
   // ̋^CsÔƂ́A͂m肳ĂȂ΁A肵Ȃ
   if (pimpl->typing_mode_ == ShimonokuTyping) {
