@@ -84,6 +84,9 @@ public:
     \retval false ͕Ȃ
   */
   bool textEmpty(void);
+
+  void placeLeftNum(size_t left_num);
+  void removeLeftNum(void);
 };
 
 #endif /* !SHIMONOKU_INPUT_H */
