@@ -14,21 +14,23 @@
 // ftHgݒ
 enum {
   DefaultPracticeNum = 5,
+  GraphHistoryMax = 30,
 };
 
 
 // VXeݒ
 enum {
-  GameSchedulerId,
+  UserMax = 5,
 };
 
 // Q[ݒ
 enum {
 #if 1
-  KaminokuPlaying = 4500,
-  ShimonokuPlaying = 3000,
+  KaminokuPlaying = 6500,
+  ShimonokuPlaying = 6000,
   YomibitoPlaying = 1000,
 #else
+  // fobOp
   KaminokuPlaying = 45,
   ShimonokuPlaying = 30,
   YomibitoPlaying = 10,
