@@ -179,7 +179,6 @@ void TextInputComponent::applyInput(const InputEvent& event,
 
   // !!! ͂ϊĂ̕\
   bool text_changed = false;
-  //Input::const_iterator rit = event.key_released.begin();
   for (Input::const_iterator it = event.key_pressed.begin();
        it != event.key_pressed.end(); ++it) {
 
@@ -203,6 +202,12 @@ void TextInputComponent::applyInput(const InputEvent& event,
         pimpl->is_erased = true;
         continue;
 
+      } else if ((it->mod_ & KMOD_SHIFT) && (it->sym_ == SDLK_0)) {
+          // SHIFT + 0 ꂽꍇAȓ͂̃T|[ĝ߂
+          // ~ ɕϊēo^
+          text_changed |= pimpl->converter->addChar('~');
+          continue;
+
       } else if ((it->unicode_ & 0xff00) || (! isprint(it->unicode_))) {
         // \łȂL[͂́AƂĈȂ
         continue;
