@@ -62,7 +62,9 @@ struct TypingTextConverter::pImpl {
       if ((a[i] == 0x0) || (b[i] == 0x0)) {
         return a[i] - b[i];
       }
-      int cmp = tolower(a[i]) - tolower(b[i]);
+
+      int cmp = (type_ == Roman) ?
+          (tolower(a[i]) - tolower(b[i])) : (a[i] - b[i]);
       if (cmp != 0) {
         return cmp;
       }
