@@ -67,3 +67,12 @@ bool beego::isHiragana(const Uint16 wch) {
     return true;
   }
 }
+
+
+void beego::uni2char(std::vector<char>& text, std::vector<Uint16>& utext) {
+
+  for (std::vector<Uint16>::iterator it = utext.begin();
+       it != utext.end(); ++it) {
+    text.push_back(0xff & *it);
+  }
+}
