@@ -55,13 +55,11 @@ class WakaDrawer {
   /*!
     \brief ͌̍XV
 
-    \param text [i] ȕ\̓͌
     \param ku_index [i] ̋̉Ԗڂ܂œ͂
     \param roman_sample [i] [}͌
     \param need_bs [i] BackSpace L[𑣂ꍇ true
   */
-  void updateInputSample(const std::vector<std::vector<Uint16> >& text,
-                         size_t ku_index,
+  void updateInputSample(size_t ku_index,
                          const std::vector<Uint16>& roman_sample,
                          bool need_bs);
 
