@@ -16,6 +16,8 @@ using namespace beego;
 
 
 int main(int argc, char *argv[]) {
+  static_cast<void>(argc);
+  static_cast<void>(argv);
 
   CdromPlayer cdrom;
 
